@@ -4,6 +4,8 @@ from .general import is_iterable
 from .general import nesting_level
 from .general import wrap_if_not_iterable
 
+from .filters import SelectByDimension
+
 from .summary_statistics import total_persistence
 from .summary_statistics import persistent_entropy
 from .summary_statistics import polynomial_function
@@ -15,4 +17,5 @@ __all__ = [
     'polynomial_function',
     'total_persistence',
     'wrap_if_not_iterable',
+    'SelectByDimension',
 ]
